using IRaCIS.Core.Domain.BaseModel;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
namespace IRaCIS.Core.Application.MassTransit.Consumer;


/// <summary>
/// QC 影像质疑待处理
/// </summary>
public class QCImageQuestionRecurringEvent : DomainEvent
{
    public Guid TrialId { get; set; }
}

/// <summary>
/// CRC 影像质疑
/// </summary>
public class CRCImageQuestionRecurringEvent : DomainEvent
{
    public Guid TrialId { get; set; }
}

/// <summary>
/// 影像质控
/// </summary>
public class ImageQCRecurringEvent : DomainEvent
{
    public Guid TrialId { get; set; }
}

//加急的待阅任务时，过10分钟，统计10分钟内该IR账号的全部待阅任务
public class UrgentIRUnReadTaskRecurringEvent : DomainEvent
{
    public Guid TrialId { get; set; }
}

/// <summary>
/// 定时提醒
/// </summary>
public class SystemDocumentErverDayEvent : DomainEvent
{

}


public class SystemDocumentPublishEvent : DomainEvent
{
    public List<Guid> Ids { get; set; }

    /// <summary>
    /// 新增的需要发送邮件的用户角色ID列表
    /// 如果为null或空，则发送给所有相关角色
    /// </summary>
    public List<Guid> NewUserTypeIds { get; set; }
}


/// <summary>
/// 定时提醒
/// </summary>
public class TrialDocumentErverDayEvent : DomainEvent
{

}


public class TrialDocumentPublishEvent : DomainEvent
{
    public List<Guid> Ids { get; set; }

    /// <summary>
    /// 新增的需要发送邮件的用户角色ID列表
    /// 如果为null或空，则发送给所有相关角色
    /// </summary>
    public List<Guid> NewUserTypeIds { get; set; }
}


